# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class ArtifactChange(object):
    """A change to a single artifact."""

    artifact_location = attr.ib(metadata={"schema_property_name": "artifactLocation"})
    replacements = attr.ib(metadata={"schema_property_name": "replacements"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
