# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class ArtifactContent(object):
    """Represents the contents of an artifact."""

    binary = attr.ib(default=None, metadata={"schema_property_name": "binary"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    rendered = attr.ib(default=None, metadata={"schema_property_name": "rendered"})
    text = attr.ib(default=None, metadata={"schema_property_name": "text"})
