# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class CodeFlow(object):
    """A set of threadFlows which together describe a pattern of code execution relevant to detecting a result."""

    thread_flows = attr.ib(metadata={"schema_property_name": "threadFlows"})
    message = attr.ib(default=None, metadata={"schema_property_name": "message"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
